@@ -3,12 +3,13 @@ package Log::Dispatch::Screen;
 use strict;
 use warnings;
 
-our $VERSION = '2.49';
+our $VERSION = '2.50';
 
 use Log::Dispatch::Output;
 
 use base qw( Log::Dispatch::Output );
 
+use Encode qw( encode );
 use IO::Handle;
 use Params::Validate qw(validate BOOLEAN);
 Params::Validate::validation_options( allow_extra => 1 );
@@ -30,12 +31,7 @@ sub new {
         }
     );
 
-    my $fh = IO::Handle->new;
-    $fh->fdopen( $p{stderr} ? fileno(*STDERR) : fileno(*STDOUT), 'w' );
-    $fh->autoflush(1);
-    binmode $fh, ':encoding(UTF-8)' if $p{utf8};
-
-    my $self = bless { fh => $fh }, $class;
+    my $self = bless \%p, $class;
     $self->_basic_init(%p);
 
     return $self;
@@ -45,7 +41,14 @@ sub log_message {
     my $self = shift;
     my %p    = @_;
 
-    $self->{fh}->print( $p{message} );
+    my $message
+        = $self->{utf8} ? encode( 'UTF-8', $p{message} ) : $p{message};
+    if ( $self->{stderr} ) {
+        print STDERR $message;
+    }
+    else {
+        print STDOUT $message;
+    }
 }
 
 1;
@@ -62,7 +65,7 @@ Log::Dispatch::Screen - Object for logging to the screen
 
 =head1 VERSION
 
-version 2.49
+version 2.50
 
 =head1 SYNOPSIS
 
